@@ -1,9 +1,9 @@
-rich.colors.short <- function(n){
+rich.colors.short <- function(n,alpha=1){
   # a subset of rich.colors by Arni Magnusson from the gregmisc package
   x <- seq(0, 1, length = n)
   r <- 1/(1 + exp(20 - 35 * x))
   g <- pmin(pmax(0, -0.8 + 6 * x - 5 * x^2), 1)
   b <- dnorm(x, 0.25, 0.15)/max(dnorm(x, 0.25, 0.15))
   rgb.m <- matrix(c(r, g, b), ncol = 3)
-  rich.vector <- apply(rgb.m, 1, function(v) rgb(v[1], v[2], v[3]))
+  rich.vector <- apply(rgb.m, 1, function(v) rgb(v[1], v[2], v[3], alpha=alpha))
 }
